@@ -1,5 +1,4 @@
-
-'Generated protocol buffer code.'
+"""Generated protocol buffer code."""
 from google.protobuf import descriptor as _descriptor
 from google.protobuf import descriptor_pool as _descriptor_pool
 from google.protobuf import message as _message
@@ -11,8 +10,8 @@ DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%cosmos/evidence/v
 _GENESISSTATE = DESCRIPTOR.message_types_by_name['GenesisState']
 GenesisState = _reflection.GeneratedProtocolMessageType('GenesisState', (_message.Message,), {'DESCRIPTOR': _GENESISSTATE, '__module__': 'cosmos.evidence.v1beta1.genesis_pb2'})
 _sym_db.RegisterMessage(GenesisState)
-if (_descriptor._USE_C_DESCRIPTORS == False):
+if _descriptor._USE_C_DESCRIPTORS == False:
     DESCRIPTOR._options = None
     DESCRIPTOR._serialized_options = b'Z-github.com/cosmos/cosmos-sdk/x/evidence/types'
     _GENESISSTATE._serialized_start = 93
-    _GENESISSTATE._serialized_end = 147
+    _GENESISSTATE._serialized_end = 147
\ No newline at end of file
