@@ -1,5 +1,4 @@
-
-'Generated protocol buffer code.'
+"""Generated protocol buffer code."""
 from google.protobuf import descriptor as _descriptor
 from google.protobuf import descriptor_pool as _descriptor_pool
 from google.protobuf import message as _message
@@ -10,8 +9,8 @@ DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1ctendermint/sto
 _BLOCKSTORESTATE = DESCRIPTOR.message_types_by_name['BlockStoreState']
 BlockStoreState = _reflection.GeneratedProtocolMessageType('BlockStoreState', (_message.Message,), {'DESCRIPTOR': _BLOCKSTORESTATE, '__module__': 'tendermint.store.types_pb2'})
 _sym_db.RegisterMessage(BlockStoreState)
-if (_descriptor._USE_C_DESCRIPTORS == False):
+if _descriptor._USE_C_DESCRIPTORS == False:
     DESCRIPTOR._options = None
     DESCRIPTOR._serialized_options = b'Z7github.com/tendermint/tendermint/proto/tendermint/store'
     _BLOCKSTORESTATE._serialized_start = 50
-    _BLOCKSTORESTATE._serialized_end = 97
+    _BLOCKSTORESTATE._serialized_end = 97
\ No newline at end of file
